OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informationen zur CPU nicht verfügbar",
    "CPU Usage:" : "CPU-Auslastung:",
    "Load average: {percentage} % ({load}) last minute" : "Durchschnittliche Last: {percentage} % ({load}) in der letzen Minute",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) letzte Minute\n{last5MinutesPercentage} % ({last5Minutes}) letzte 5 Minuten\n{last15MinutesPercentage} % ({last15Minutes}) letzte 15 Minuten",
    "RAM Usage:" : "Speicherauslastung:",
    "SWAP Usage:" : "SWAP-Auslastung:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Gesamt: {memTotalBytes}/Aktuelle Nutzung: {memUsageBytes}",
    "RAM info not available" : "Informationen zum RAM nicht verfügbar",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Gesamt: {swapTotalBytes}/Aktuelle Nutzung: {swapUsageBytes}",
    "SWAP info not available" : "Informationen zum SWAP nicht verfügbar",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Nicht unterstützt!",
    "Press ⌘-C to copy." : "Zum Kopieren ⌘-C drücken.",
    "Press Ctrl-C to copy." : "Zum Kopieren Strg-C drücken.",
    "Unknown" : "Unbekannt",
    "%1$d days, %2$d hours, %3$d minutes, %4$d seconds" : "%1$d Tage, %2$d Stunden, %3$d Minuten, %4$d Sekunden",
    "%1$d hours, %2$d minutes, %3$d seconds" : "%1$d Stunden, %2$d Minuten, %3$d Sekunden",
    "System" : "System",
    "Monitoring" : "Information",
    "Monitoring app with useful server information" : "Monitoring-App mit nützlichen Serverinformationen",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Zeigt nützliche Informationen des Servers an wie z.B. CPU-Last, Arbeitsspeicherauslastung, Massenspeicherauslastung, Anzahl der Benutzer, usw.",
    "Operating System:" : "Betriebssystem:",
    "CPU:" : "Prozessor:",
    "threads" : "Threads",
    "Memory:" : "Speicher:",
    "Server time:" : "Serverzeit:",
    "Uptime:" : "Betriebszeit:",
    "Temperature" : "Temperatur",
    "Load" : "Auslastung",
    "Memory" : "Speicher",
    "Disk" : "Festplatte",
    "Mount:" : "Mount:",
    "Filesystem:" : "Dateisystem:",
    "Size:" : "Größe:",
    "Available:" : "Verfügbar:",
    "Used:" : "Verwendet:",
    "Files:" : "Dateien:",
    "Storages:" : "Speicher:",
    "Free Space:" : "Freier Speicherplatz:",
    "Network" : "Netzwerk",
    "Hostname:" : "Hostname:",
    "Gateway:" : "Gateway:",
    "Status:" : "Status:",
    "Speed:" : "Geschwindigkeit:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktive Benutzer",
    "Last hour" : "In der letzten Stunde",
    "%s%% of all users" : "%s%% aller Benutzer",
    "Last 24 Hours" : "In den letzten 24 Stunden",
    "Last 7 Days" : "In den letzten 7 Tagen",
    "Last 30 Days" : "In den letzten 30 Tagen",
    "Shares" : "Freigaben",
    "Users:" : "Benutzer:",
    "Groups:" : "Gruppen:",
    "Links:" : "Links:",
    "Emails:" : "E-Mails:",
    "Federated sent:" : "Federated gesendet:",
    "Federated received:" : "Federated empfangen:",
    "Talk conversations:" : "Talk-Unterhaltungen:",
    "PHP" : "PHP",
    "Version:" : "Version:",
    "Memory limit:" : "Speicherlimit:",
    "MB" : "MB",
    "Max execution time:" : "Maximale Ausführungszeit:",
    "seconds" : "Sekunden",
    "Upload max size:" : "Maximale Größe zum Hochladen:",
    "OPcache Revalidate Frequency:" : "OPcache-Revalidierungshäufigkeit:",
    "Extensions:" : "Erweiterungen:",
    "Unable to list extensions" : "Erweiterungen können nicht aufgelistet werden",
    "PHP Info:" : "PHP Info:",
    "Show phpinfo" : "phpinfo anzeigen",
    "FPM worker pool" : "FPM-Worker-Pool",
    "Pool name:" : "Pool-Name:",
    "Pool type:" : "Pool-Typ:",
    "Start time:" : "Startzeit:",
    "Accepted connections:" : "Akzeptierte Verbindungen:",
    "Total processes:" : "Prozesse insgesamt:",
    "Active processes:" : "Aktive Prozesse:",
    "Idle processes:" : "Leerlaufprozesse:",
    "Listen queue:" : "Warteschlange (Listen-Queue)",
    "Slow requests:" : "Langsame Anfragen:",
    "Max listen queue:" : "Maximale Warteschlange (Listen-Queue):",
    "Max active processes:" : "Maximal aktive Prozesse:",
    "Max children reached:" : "Maximal erreichte Kindzahl:",
    "Database" : "Datenbank",
    "Type:" : "Art:",
    "External monitoring tool" : "Externes Überwachungsprogramm",
    "Use this end point to connect an external monitoring tool:" : "Diesen Endpunkt verwenden, um mit einem externen Überwachungstool zu verbinden:",
    "Copy" : "Kopieren",
    "Output in JSON" : "Ausgabe in JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Abschnitt \"Apps\" überspringen (das Einschließen des Abschnitts \"Apps\" sendet eine externe Anfrage an den App Store)",
    "Skip server update" : "Serveraktualisierung überspringen",
    "To use an access token, please generate one then set it using the following command:" : "Um ein Zugriffstoken zu verwenden, generieren Sie bitte eines und legen Sie es mit dem folgenden Befehl fest:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Übergeben Sie dann das Token mit dem Header \"NC-Token\" durch Aufrufen der obigen URL.",
    "Unknown Processor" : "Unbekannter Prozessor"
},
"nplurals=2; plural=(n != 1);");
